bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 17. Aventiure
___________________________________________________ #### Auentv wie Ch'r ir man klagte vn– wie man in begrvp
| ### <Do> erbiten si der nahte vn– fvren vber Rin ### von heleden chunde nimmer wirs geiaget sin ### ein tyer daz si da slugen daz weinten edeliv kint ### ia mvsin sin engelten vil gvte wigande sint ### Von grozer vbermvete mvgt ir nv horen sagn ### vn– von starcher rache do hiez Hagen tragn ### Sivride den herren von Nibelunge lant ### fvr eine kemenaten da man Chriemh' vant
###### 1016 | ### Er hiez in also toten legn an die tvr ### daz si in da solde vinden so si der gienge fvr ### hin zer mettine e daz ez wrde tac ### der div frowe Chriemh' deheine selten verlac
| ### Man lvote da zem munster nach gewonheit ### do wachte div frowe vor ir manige meit ### si bat ir balde bringen lieht un– ir gewant ### do chom ein kamerære da er Sivriden vant
###### 1018 | ### Er sach in blvtes roten sin wat was elliv naz ### daz ez sin herre wære niht enwesser daz ### hin zer kemenaten daz lieht trvog an der hant ### von dem vil leider mære sit vroe Chriemhilt ervant
###### 1019 | ### Do si mit ir frowen zem munster wolde gan ### do sprach der kamerære ia sult ir stille stan ### ez lit vor dem gademe ein ritter tot erslagn ### da begunde Chriemh' harte vnmæzliche klagn
###### 1020 | ### E daz si reht erfunde daz ez wære ir man ### an die Hagenen vrage denchen si began ### wier in wolde vristen do wart ir erste leit ### ir was alle ir freuden mit sime tode widerseit
###### 1021 | ### Do seich si zv der erden daz si niht ensprach ### die schonen frev[39r]delosen ligen man do sach ### der edeln frowen iamer wart unmazen groz ### do erschre si nach unchrefte daz al div kemenate erdoz
| ### Do sprach ir gesinde waz ob ez ist ein gast ### daz blvot ir vzem munde von hercen iamer brast ### si sprach ez ist Sivrit der min vil lieber man ### ez hat geraten Prunh' daz ez hat Hagene getan
###### 1023 | ### Div frowe bat sich wisen da si den rechen vant ### si hvop sin schone hovbet mit ir wizen hant ### swie rot er was von blvote si het in schier bechant ### do was missevarwe des chunen degenes gewant
###### 1024 | ### Do rief vil iæmerliche div kuniginne milt ### owe mir miner leide nvne ist dir din schilt ### mit swerten niht verhowen dv list ermorderot ### vn– wesse ich wer daz tæte ich riet im immer sinen tot
###### 1025 | ### Allez ir gesinde chlagt un– schre ### mit ir vil lieben frowen wande in starche we ### vmbe ir vil edeln herren den si da heten verlorn ### do het gerochen Hagene harte Prunh' zorn
###### 1026 | ### Do sprach div iamerhafte man sol hin gan ### vn– wechen die Sivrides man ### vn– sol ovch Sigemunde disiv mære sagen ### ob er mir helfen welle den herren Sivriden chlagen
| ### Do lief ein bote balde da er ligen vant ### die Sivrides helede von Nibelunge lant ### mit disen leiden mæren wachter manigen man ### die sprungen ane sinne vil balde von ir betten dan
###### 1028 | ### Ovch kom der bote <schiere> da der kunic lac ### Sigemunt der herre der slafes niht enpflac ### ich wæn sin herce im sagete daz im da was geschehn ### ern mohte sinen lieben svon lebnden nimmer me gesehn
###### 1029 | ### Wachet herre Sigemunt wande ir svlt balde gan ### ze Chriemh' miner frowen der ist ein leit getan ### daz ir vor allen leiden an ir herce gat ### daz sult ir klagen helfeo wandez ivch sere bestat
###### 1030 | ### Vf rihte sich do Sigemunt er sprach <waz> sint div leit ### der schonen Chriemh' di dv mir hast geseit ### der bote sprach mit iamer si mvoz von schulden chlagen ### ia ist von Niderlanden der chuone Sivrit erslagn
| ### Do sprach der herre Sigemvnt lat daz schimpfen sin ### vn– also bosiv mære von dem svne min ### daz ir daz saget iemen daz er si erslagn ### wande ich en chunde in nimmer vnz an min ende verklagn
###### 1032 | ### Vn– welt ir niht gelovben daz ir mich hoeret sagn ### ir mvegt wol selbe hoeren Chriemh' klagn ### vn– allez ir gesinde den Sivrides tot ### vil sere erschrach do Sigemunt des gie im groezliche not
###### 1033 | ### Mit hundert sinen mannen er von den betten spranch ### si zvchten zv den handen div scharpfen wafen lanch ### si liefen zvo dem wofe vil seneliche dan ### do chomen tusint rechen des chunen Sivri[39v]des man
###### 1034 | ### Do si so iamerliche die frowen horten chlagn ### do wande sumeliche si solden chleider tragn ### iane mohten si der sinne vor leide niht gehabn ### in was vil starchiv swêre in ir hercen begrabn
| ### Do chom der kunic Sigemunt da er Chriemh' vant ### er sprach owe der reise her in <ditzce> lant ### wer hat mich mines kindes vn– ivch iwers man ### bi so guoten friunden vergebne ane getan
###### 1036 | ### Hey solde ich den bechennen sprach daz edel wip ### holt enwrde im nimmer min herce vn– ovch der lip ### ich getæt im als leide daz die mage sin ### mit iamer mvesen weinen daz wizzet von den schulden min
###### 1037 | ### Sigemvnt mit armen den fursten vmbesloz ### do wart von sinen frivnden der iamer also groz ### daz von dem starchen wofe palas un– sal ### vn– ovch div stat ze Wormz von ir weinen erschal
###### 1038 | ### Done chunde niemen trosten daz Sivrides wip ### man zoch vz den chleidern den sinen schonen lip ### den edeln kunich riche si leiten vf den re ### do was von grozem iamer sinen luten allen we
###### 1039 | ### Do sprachen sine rechen von Nibelunge lant ### in sol immer rechen mit willen unser hant ### er ist in dirre burege der iz da hat getan ### do ilten nach gewefen alle Sivrides man
###### 1040 | ### Die vz erwelten rechen mit schilden chomen dar ### einlief hundert rechen die het an siner schar ### Sigemunt der herre den Sivrides tot ### den wolde gerne rechen des gie im wærliche not
###### 1041 | ### Sine wessen wen si solden mit strite bestan ### sine tætenz Gunther vn– sine man ### mit den der herre Sivrit an daz geiægede reit ### Chriemh' si sach gewafent do was ir grozliche leit
###### 1042 | ### Swie starch ir iamer wære vn– swie groz ir not ### do vorhte si so sere der Nibelunget tot ### von Gunthers mannen daz si ez vnderstunt ### si warnt si guotliche so frivnt noch liebe frivnde tvont
| ### Do rief div iamers riche min her Sigemunt ### wes welt ir beginnen iv enist niht rehte chunt ### ez hat der chunich Gunther so manigen chunen man ### ir sit verlorn alle welt ir mit strite si bestan
###### 1044 | ### Mit vf erburten schilden ze strite was in not ### Chriemh' div frowe bat vn– ovch gebot ### daz siz niden solden die rechen vil gemeit ### ob siz niht wenden chunde daz wære ir bedenthalben leit
###### 1045 | ### Si sprach herre Sigemunt ir svlt iz lazen stan ### vnz iz sich baz gefvege so wil ich minen man ### immer mit iv rechen der mir in hat benomen ### wirde ich des bewiset ich sol im schædeliche komen
###### 1046 | ### Ez ist der vbermveten hie bi Rine vil ### da von ich iv des strites raten niene wil ### si habent wider einen ie wol drizzech man [4or] ### nv laz in got gelinngen als si an vns gedienet han
###### 1047 | ### Ir sult hie beliben vn– dolt mit mir div leit ### so ez tagen beginne ir helde vil gemeit ### so helfet mir besarchen den minen lieben man ### do sprachen die degene daz sol werden getan
| ### Nvne chuondiv niemen daz wnder wol gesagn ### von rittern vn– frowen wie man die horte klagn ### do wart man des wofes in der stete gewar ### vil der burgære dic chomen gahende dar
###### 1049 | ### Si klagten mit den gesten wande in was starche leit ### die Sivrides schulde in niemen het geseit ### wa von der edele reche verlvr den sinen lip ### do weinten mit den frowen der gvten chavflvte wip
###### 1050 | ### Smide hiez man gahen bewrchen einen sarch ### von edelm mærmelsteine vil michel vn– starch ### man hiez in vaste binden mit gespenge gvot ### do was al den lvten harte trurich der mvot
###### 1051 | ### Div naht div was zergangen man sagt iz wolde tagen ### do bat div edele frowe zv dem mvnster tragen ### den vil edeln toten ir vil lieben man ### swaz er da frivnde hete die sah man weinende gan
###### 1052 | ### Do man in zem <munster> brahte vil der glocken chlanc ### man horte von den pfaffen vil michel gesanc ### do chom der chunic Gunther mit den sinen man ### mit im der grimme Hagene zv dem wofe gegan
| ### Er sprach vil liebiv swester owe der laide din ### daz wir der starchen leide niht mohten vber sin ### wir mvzen klagn immer den sinen schonen lip ### daz tvot ir ane schulde sprach do daz iamerhafte wip
###### 1054 | ### Wær iv dar vmbe leide sone wær es niht geschehn ### ir hetet min vergezzen des mage ich wol nv iehn ### da ich da wart gescheiden von mime lieben man ### daz wolde got von himele wær ez mir selber getan
###### 1055 | ### Dir ist von minen lvten leides niht geschehen ### sprach der kunic Gunther des wil ich dir veriehn ### die wellen sin vnschuldich die heizet naher gen ### sprach si zvo der bare daz wir die warheit versten
###### 1056 | ### Daz ist ein michel wnder vil dicke ez noch geschiht ### swa man den mortmeilen bi dem toten siht ### so blvtent im die wnden als ovch da geschach ### da von man die sculde da ze Hagene gesach
| ### Die wnden vluzzen sere also si taten ê ### die ê da sere chlageten des wart nv michel me ### do sprach der kunich Gunther ich wilz ivch wizzen lan ### in slvgen schachære Hagene hat es niht getan
###### 1058 | ### Si sprach die selben schachman sint mir wol bechant ### got laz iz noch errechen siner friunde hant ### Gunther vn– Hagene ia habt ir ez getan ### die Sivrides rechen heten do ze strite wan [4ov]
###### 1059 | ### Do sprach aber Chriemh' nv dolt mit mir die not ### do chomen dise beide da si in funden tot ### Gernot ir bruder vn– Giselher daz kint ### in triwen si in chlageten mit den anderen sint
###### 1060 | ### Si weinten innekliche den Chriemh' man ### man solde messe singin zvo dem munster dan ### giengen allenthalben man <wip> unt kint ### die sin doch lihte enbaren die weinten Sivriden sint
| ### Gernot vn– Giselher sprachen swester min ### nv troste dich nach tode als ez doch mvoz nvo sin ### wir wellens dich ergezzen die wil unt wir gelebn ### done chunde ir trost decheinen zer werlde niemen gegebn
###### 1062 | ### Sin sarch der was bereitet vmben mitten tac ### man hvb in von der bare da er vof lac ### noch enwolde si den rechen lazen niht begraben ### des mvsen al die lvte vil michel arebeite habn
###### 1063 | ### In einen richen pfellel man den toten want ### ich wæne man da iemen ane weinen vant ### do chlagete hercenliche Vote ein edel wip ### vn– allez ir gesinde den sinen wætlichen lip
###### 1064 | ### Do man daz gehorte daz man zem munster sanc ### vn– in gesarchet hete vil groz wart der gedranc ### durch willen siner sele waz opfers rnan do truoch ### er hete bi den vinden gvoter frivnde doch genvoch
| ### Do man da gote gediente daz volch hvop sich von dan ### do sprach div kuniginne irn svlt niht eine lan ### mich hinte bewachen den voz erwelten degn ### ist an sime libe al min frevde gelegn
###### 1066 | ### Dri tage un– dri nahte wil ich in lazen stan ### vnz ich mich wol geniete mins vil lieben man ### waz ob daz got gebivtet daz mich ovch nimt der tot ### so wære wol verendet min armer <Chriemhilde> not
###### 1067 | ### Zen herbergen giengen die lvte von der stat ### pfaffen un– mveniche si beliben bat ### un– allez sin gesinde daz sin von rehte pflac ### si heten naht vil arge vn– ovch vil mvelichen tac
###### 1068 | ### Ane ezzen vn– ane trinchen beleip da manic man ### die ez nemen wolden den wart daz chunt getan ### man gæb es in den vollen daz schvof Sigemunt ### do was den Nibelungen michel arebeiten chunt
###### 1069 | ### Die drîe tagecite so wir horn sagn ### di da singen <chunden> da si mvsn tragen ### vil michel arebeite durch ir hercen ser ### si baten vmbe die sele des rechen chven vn– her
| ### Vrbor vf der erden div teiltes in div lant ### swa so man div chloster un– gvte lvte vant ### ovch hiez si gebn den armen der sinen habe genvoch ### si tet dem wol geliche daz si im holden willen trvoch
###### 1071 | ### An dern dritten morgen ze rehter messe cît ### so was bi dem munster der chirchof also wit ### von den lantlvten weinens harte vol ### si dienten im nach tode als man lieben frivnden sol
###### 1072 | ### In den tagen vieren ist uns [41r]gesagt daz ### ze drizzech tusint marchen oder dannoch baz ### wart durch sine sele den armen da gegebn ### do was gelegn ringe sin groziv <schoene> vn– ovch sin lebn
###### 1073 | ### Do gote wart da gedienet vn– daz man da gesanch ### mit ungefugem leide vil des volches ranch ### man hiez in vz dem munster zv dem grabe tragn ### die sin doch liht enbaren die sah man weinen vn– klagn
###### 1074 | ### Vil lvote schriende daz volch gie mit im dan ### vro enwas da niemen weder wip noch man ### ê er begrabn wrde man sanch un– las ### hey waz der wisen pfaffen bi siner bivilde was
| ### E daz zem grabe choeme daz Sivrides wip ### do ranch mit solhem iamer der ir getriwer lip ### daz man si mit wazzer vil diche da begoz ### ez was ir ungemvete hart vnmæzlich groz
###### 1076 | ### Ez was ein michel wnder daz si ie genas ### mit klage ir helfende vil manic frowe was ### do sprach div kuniginne ir Sivrides man ### ir sult durch iwer triwe dise genade an mir began
###### 1077 | ### Lat mir nach mime leide daz chleine liep geschehn ### daz ich sin schone hovbt noch eines mvze sehn ### do bat sis also lange mit iamers siten starch ### daz man wider vf brechen mvose den herlichen sarch
###### 1078 | ### Do brahte man die frowen da si in ligen vant ### si hvop sin schoene hovbet mit ir wizen hant ### do chustes also toten den edeln ritter gvot ### ir vil liehten ovgen vor leide weinten do blvot
| ### Ein iæmerlichez scheiden wart do da getan ### man trvoch die frowen dannen sine mohte niht gegan ### do lac in unsinne daz herliche wip ### vor leide moht ersterben der ir vil wnnekliche lip
###### 1080 | ### Do marn den edeln herren hete nv begrabn ### leit ane maze sah man die alle habn ### die mit im chomen waren von Nibelunge lant ### vil selten wol gemvten man do Sigemunden vant
###### 1081 | ### Do was der etelicher der drier tage lanc ### vor dem starchen leide niht az noch entranch ### doch enmohten si dem libe so gar geswichen niht ### si nerten sich nach iamer so noch genvogen geschiht
###### 1082 | ### Chriemh' unversunnen in vnchreften lac ### den tac un– den abent vnz an den andern tac ### swaz iemen sprechen chvnde daz was ir gar vnchunt ### in den selben noeten lage ovch der kunich Sigemunt
###### 1083 | ### Vil chume wart der herre wider ze sinnen braht ### von dem starchen leide chranch was gar sin maht ### daz enwas niht wnder do sprachen sine man ### herre ir sult ze lande wir mugen niht langer hie bestan

<<< Übersicht <<< vorige Seite nächste Seite >>>